@@ -12,9 +12,10 @@ from labelme import utils
 
 
 def main():
-    logger.warning('This script is aimed to demonstrate how to convert the'
-                   'JSON file to a single image dataset, and not to handle'
-                   'multiple JSON files to generate a real-use dataset.')
+    logger.warning('This script is aimed to demonstrate how to convert the '
+                   'JSON file to a single image dataset.')
+    logger.warning("It won't handle multiple JSON files to generate a "
+                   "real-use dataset.")
 
     parser = argparse.ArgumentParser()
     parser.add_argument('json_file')
@@ -56,8 +57,9 @@ def main():
     label_names = [None] * (max(label_name_to_value.values()) + 1)
     for name, value in label_name_to_value.items():
         label_names[value] = name
+
     lbl_viz = imgviz.label2rgb(
-        label=lbl, img=imgviz.rgb2gray(img), label_names=label_names, loc='rb'
+        label=lbl, img=imgviz.asgray(img), label_names=label_names, loc='rb'
     )
 
     PIL.Image.fromarray(img).save(osp.join(out_dir, 'img.png'))
