@@ -67,8 +67,11 @@ class Canvas(QtWidgets.QWidget):
         self._hideBackround = False
         self.hideBackround = False
         self.hShape = None
+        self.prevhShape = None
         self.hVertex = None
+        self.prevhVertex = None
         self.hEdge = None
+        self.prevhEdge = None
         self.movingShape = False
         self._painter = QtGui.QPainter()
         self._cursor = CURSOR_DEFAULT
@@ -151,7 +154,10 @@ class Canvas(QtWidgets.QWidget):
         if self.hShape:
             self.hShape.highlightClear()
             self.update()
-        self.hVertex, self.hShape, self.hEdge = None, None, None
+        self.prevhShape = self.hShape
+        self.prevhVertex = self.hVertex
+        self.prevhEdge = self.hEdge
+        self.hShape = self.hVertex = self.hEdge = None
 
     def selectedVertex(self):
         return self.hVertex is not None
@@ -245,9 +251,9 @@ class Canvas(QtWidgets.QWidget):
             if index is not None:
                 if self.selectedVertex():
                     self.hShape.highlightClear()
-                self.hVertex = index
-                self.hShape = shape
-                self.hEdge = index_edge
+                self.prevhVertex = self.hVertex = index
+                self.prevhShape = self.hShape = shape
+                self.prevhEdge = self.hEdge = index_edge
                 shape.highlightVertex(index, shape.MOVE_VERTEX)
                 self.overrideCursor(CURSOR_POINT)
                 self.setToolTip(self.tr("Click & drag to move point"))
@@ -257,9 +263,10 @@ class Canvas(QtWidgets.QWidget):
             elif shape.containsPoint(pos):
                 if self.selectedVertex():
                     self.hShape.highlightClear()
+                self.prevhVertex = self.hVertex
                 self.hVertex = None
-                self.hShape = shape
-                self.hEdge = index_edge
+                self.prevhShape = self.hShape = shape
+                self.prevhEdge = self.hEdge = index_edge
                 self.setToolTip(
                     self.tr("Click & drag to move shape '%s'") % shape.label)
                 self.setStatusTip(self.toolTip())
@@ -272,13 +279,11 @@ class Canvas(QtWidgets.QWidget):
         self.vertexSelected.emit(self.hVertex is not None)
 
     def addPointToEdge(self):
-        if (self.hShape is None and
-                self.hEdge is None and
-                self.prevMovePoint is None):
-            return
-        shape = self.hShape
-        index = self.hEdge
+        shape = self.prevhShape
+        index = self.prevhEdge
         point = self.prevMovePoint
+        if shape is None or index is None or point is None:
+            return
         shape.insertPoint(index, point)
         shape.highlightVertex(index, shape.MOVE_VERTEX)
         self.hShape = shape
@@ -287,11 +292,10 @@ class Canvas(QtWidgets.QWidget):
         self.movingShape = True
 
     def removeSelectedPoint(self):
-        if (self.hShape is None and
-                self.prevMovePoint is None):
-            return
-        shape = self.hShape
+        shape = self.prevhShape
         point = self.prevMovePoint
+        if shape is None or point is None:
+            return
         index = shape.nearestVertex(point, self.epsilon)
         shape.removePoint(index)
         # shape.highlightVertex(index, shape.MOVE_VERTEX)
